@@ -8,6 +8,10 @@
 #include <qjson/qobjecthelper.h>
 #include <qfacebook.h>
 
+#include "maps/mapswidget.h"
+#include "maps/marker.h"
+#include <QGeoServiceProvider>
+
 namespace Ui {
     class CheckinWindow;
 }
@@ -36,6 +40,11 @@ private:
     QStringList friendIds;
     QString m_longitude;
     QString m_latitude;
+    QString m_locationName;
+    MapsWidget *m_mapsWidget;
+    QGeoServiceProvider *serviceProvider;
+    MarkerManager *markerManager;
+    void initializeMapWidget();
 
 private slots:
     void onRecepientsSelected(QList<QListWidgetItem*>);
