@@ -21,15 +21,18 @@ public:
 
 signals:
     void addImage(QString imageUrl);
+    void uploadImages(QStringList list);
 
 private:
     Ui::ImageUploadDialog *ui;
+    QStringList m_files;
 
 private slots:
     void onPhotoClicked(QListWidgetItem*);
     void onLocalFileButtonClicked();
     void onCameraButtonClicked();
     void onImageReceived(QString filename);
+    void accept();
 };
 
 #endif // IMAGEUPLOADDIALOG_H
