@@ -15,13 +15,23 @@ int main(int argc, char *argv[])
 
     QTime t(0,0);
     t.start();
-    MainWindow w;
-    qDebug() << "Startup took" << t.elapsed() << "ms";
-#ifdef Q_WS_S60
-    w.showMaximized();
-#else
-    w.show();
+    if (QCoreApplication::arguments().contains("--widget")) {
+        // do stuff
+    } else {
+        MainWindow w;
+        qDebug() << "Startup took" << t.elapsed() << "ms";
+
+#ifdef Q_WS_MAEMO_5
+        if (!QDBusConnection::sessionBus().isConnected()) {
+            qWarning("Cannot connect to the D-Bus session bus.");
+        }
 #endif
 
-    return a.exec();
+#ifdef Q_WS_S60
+        w.showMaximized();
+#else
+        w.show();
+#endif
+        return a.exec();
+    }
 }
