@@ -53,6 +53,9 @@ public:
     void getPixmapFromUserId(QString userId);
     void addLink(QString url, QString linkName, QString linkDescription, QString linkPixmap);
     void setToName(QString name, QString id);
+    void setType(QString type);
+    void setObjectId(QString objectId);
+    QString type();
 
 protected:
     void paintEvent(QPaintEvent *);
@@ -83,6 +86,9 @@ private:
     QString likes;
     QString userId;
     QString m_toUserId;
+    QString m_postType;
+    QString m_objectId;
+    QString m_linkUrl;
     bool isLikedByMe;
     bool isDeletable;
     bool isComment;
@@ -104,6 +110,7 @@ private slots:
     void showContextMenu(QPoint point);
     void onToNameClicked();
     void onLinkActivated(QString url);
+    void onPhotoClicked();
 };
 
 #endif // NEWSFEEDPOST_H
