@@ -5,7 +5,9 @@
 #include <QNetworkAccessManager>
 #include <QDebug>
 #include <QFileDialog>
+#include <QPointer>
 #include <qfacebook.h>
+#include "newsfeedpost.h"
 
 namespace Ui {
     class PhotoWindow;
@@ -27,11 +29,14 @@ public:
     void setPixmap(QPixmap pixmap);
     void setComments(QVariantList comments);
     void setTags(QVariantList tags);
+    void getCommentsForPhoto(QString id);
 
 private:
     Ui::PhotoWindow *ui;
     QFacebook *qfacebook;
     QNetworkReply *reply;
+    QFacebookReply *commentsReply;
+    QFacebookReply *commentReply;
     QString accessToken;
     QNetworkAccessManager *nam;
     QNetworkReply *m_downloadReply;
@@ -41,13 +46,18 @@ private:
     QVariantList m_tags;
     QString m_photoUrl;
     QString m_downloadLocation;
-    QList<QWidget*> commentsList;
+    QString m_myId;
+    QList<NewsFeedPost*> commentsList;
 
 private slots:
     void onReplyReceived();
     void onClicked(QPoint);
     void downloadPhoto();
     void onDownloadFinished();
+    void onGotComments();
+    void onCommentButtonClicked();
+    void onCommentReplyReceived();
+    void onCommentDeleted(QObject *pointer);
 };
 
 #endif // PHOTOWINDOW_H
