@@ -4,6 +4,10 @@
 #include <QMainWindow>
 #include <QDebug>
 #include <QSettings>
+#include <QDialog>
+#include <QListWidget>
+#include <QListWidgetItem>
+#include <QPointer>
 #include <qfacebook.h>
 #include "newsfeedpost.h"
 #ifndef Q_WS_MAEMO_5
@@ -28,8 +32,9 @@ private:
     Ui::SinglePostWindow *ui;
     QString accessToken;
     QFacebook *qfacebook;
-    QFacebookReply *reply;
-    QFacebookReply *commentReply;
+    QPointer<QFacebookReply> reply;
+    QPointer<QFacebookReply> commentReply;
+    QPointer<QFacebookReply> likersReply;
     QString postId;
     QList<NewsFeedPost*> posts;
     QNetworkAccessManager *nam;
@@ -43,6 +48,9 @@ private slots:
     void orientationChanged();
     void onPostDestroyed(QObject*);
     void onNameClicked(QString,QString);
+    void onLinkActivated(QString);
+    void onGotLikers();
+    void onLikerActivated(QListWidgetItem*);
 };
 
 #endif // SINGLEPOSTWINDOW_H
